@@ -1,4 +1,3 @@
-import json
 import logging
 import os
 import urllib
@@ -9,13 +8,13 @@ from .utils import (
     _check_call,
     _get_juju_home,
     extract_zip,
+    get_qualified_charm_url,
     path_join,
     path_exists,
+    STORE_URL,
     temp_file,
     yaml_load)
 
-STORE_URL = "https://store.juju.ubuntu.com"
-
 
 class Charm(object):
 
@@ -90,7 +89,8 @@ class Charm(object):
 
     def fetch(self):
         if self._charm_url:
-            return self._fetch_store_charm()
+            self._fetch_store_charm()
+            return
         elif not self.branch:
             self.log.warning("Invalid charm specification %s", self.name)
             return
@@ -107,22 +107,11 @@ class Charm(object):
     def _fetch_store_charm(self, update=False):
         cache_dir = self._get_charm_store_cache()
         self.log.debug("Cache dir %s", cache_dir)
-        qualified_url = None
 
         if os.path.exists(cache_dir) and not update:
             return
 
-        # If we have a qualified url, check cache and move on.
-        parts = self.charm_url.rsplit('-', 1)
-        if len(parts) > 1 and parts[-1].isdigit():
-            qualified_url = self.charm_url
-
-        if not qualified_url:
-            info_url = "%s/charm-info?charms=%s" % (STORE_URL, self.charm_url)
-            fh = urllib.urlopen(info_url)
-            content = json.loads(fh.read())
-            rev = content[self.charm_url]['revision']
-            qualified_url = "%s-%d" % (self.charm_url, rev)
+        qualified_url = get_qualified_charm_url(self.charm_url)
 
         self.log.debug("Retrieving store charm %s" % qualified_url)
 
@@ -135,7 +124,6 @@ class Charm(object):
             shutil.copyfileobj(ufh, fh)
             fh.flush()
             extract_zip(fh.name, self.path)
-
         self.config
 
     def _get_charm_store_cache(self):
