@@ -17,7 +17,7 @@ import time
 from deployer.config import ConfigStack
 from deployer.env import select_runtime
 from deployer.action import diff, importer
-from deployer.utils import ErrorExit, setup_logging
+from deployer.utils import ErrorExit, setup_logging, get_env_name
 
 
 def setup_parser():
@@ -136,7 +136,7 @@ def run():
     options = parser.parse_args()
 
     if options.description:
-        print "Tool for declarative management of complex deployments."
+        print("Tool for declarative management of complex deployments.")
         sys.exit(0)
 
     # Debug implies watching and verbose
@@ -147,14 +147,15 @@ def run():
     log = logging.getLogger("deployer.cli")
     start_time = time.time()
 
+    env_name = get_env_name(options.juju_env)
     try:
-        env = select_runtime(options.juju_env, options)
+        env = select_runtime(env_name, options)
     except OSError as e:
         if e.errno != errno.ENOENT:
             raise
         log.error("No juju binary found, have you installed juju?")
         sys.exit(1)
-    log.debug('Using runtime %s', env.__class__.__name__)
+    log.debug('Using runtime %s on %s', env.__class__.__name__, env_name)
 
     config = ConfigStack(options.configs or [], options.series)
 
@@ -179,7 +180,7 @@ def run():
                         options.find_service)
         else:
             log.info("Service: %s address: %s", options.find_service, address)
-            print address
+            print(address)
         sys.exit(0)
 
     # Just resolve/retry hooks in the environment
@@ -198,7 +199,7 @@ def run():
 
     # Just list the available deployments
     if options.list_deploys:
-        print "\n".join(sorted(config.keys()))
+        print("\n".join(sorted(config.keys())))
         sys.exit(0)
 
     # Do something to a deployment
