@@ -16,8 +16,9 @@ class ConfigStack(object):
 
     log = logging.getLogger("deployer.config")
 
-    def __init__(self, config_files):
+    def __init__(self, config_files, cli_series=None):
         self.config_files = config_files
+        self.cli_series = cli_series
         self.data = {}
         self.yaml = {}
         self.include_dirs = []
@@ -60,6 +61,8 @@ class ConfigStack(object):
             raise ErrorExit()
         deploy_data = self.data[key]
         deploy_data = self._resolve_inherited(deploy_data)
+        if self.cli_series:
+            deploy_data['series'] = self.cli_series
         return Deployment(
             key, deploy_data, self.include_dirs,
             repo_path=os.environ.get("JUJU_REPOSITORY", ""))
