@@ -47,6 +47,10 @@ class Deployment(object):
         services.sort(self._placement_sort)
         return services
 
+    def get_service_names(self):
+        """Return a sequence of service names for this deployment."""
+        return self.data.get('services', {}).keys()
+
     @staticmethod
     def _placement_sort(svc_a, svc_b):
         if svc_a.unit_placement:
