@@ -168,6 +168,5 @@ class MemoryEnvironment(object):
         """ Return all services status """
         return {'services': self._services}
 
-    def wait_for_units(
-            self, timeout, goal_state="started", watch=False, no_exit=False):
+    def wait_for_units(self, *args, **kwargs):
         pass
