@@ -77,9 +77,26 @@ class PyEnvironment(BaseEnvironment):
     def status(self):
         return self.get_cli_status()
 
-    def wait_for_units(
-            self, timeout, goal_state="started", watch=False, no_exit=False):
+    def log_errors(self, errors):
+        """Log the given unit errors.
 
+        This can be used in the WaitForUnits error handling machinery, e.g.
+        see deployer.watchers.log_on_errors.
+        """
+        messages = [
+            'unit: {unit[name]}: machine: {unit[machine]} '
+            'agent-state: {unit[agent-state]}'.format(unit=error)
+            for error in errors
+        ]
+        self.log.error(
+            'The following units had errors:\n  {}'.format(
+                '   \n'.join(messages)))
+
+    def wait_for_units(
+            self, timeout, goal_state="started", watch=False, services=None,
+            on_errors=None):
+        # Note that the services keyword argument is ignored in this pyJuju
+        # implementation: we wait for all the units in the environment.
         max_time = time.time() + timeout
         while max_time > time.time():
             status = self.status()
@@ -111,15 +128,4 @@ class PyEnvironment(BaseEnvironment):
             if not pending and not errors:
                 break
             if errors:
-                if no_exit:
-                    raise UnitErrors(errors)
-                else:
-                    error_units = [
-                        "unit: %s: machine: %s agent-state: %s" % (
-                            u["name"], u["machine"], u["agent-state"]
-                            )
-                        for u in errors]
-                    self.log.error(
-                        "The following units had errors:\n  %s" % (
-                            "   \n".join(error_units)))
-                    raise ErrorExit()
+                on_errors(errors)
