@@ -126,6 +126,13 @@ class ConfigTest(Base):
                    ('nova-cloud-controller', 'mysql')]
         self.assertEquals(ex_rels, list(deployment.get_relations()))
 
+    def test_config_series_override(self):
+        config = ConfigStack(['configs/wiki.yaml'], 'trusty')
+        config.load()
+        result = config.get("wiki")
+        self.assertTrue(isinstance(result, Deployment))
+        self.assertEquals(result.series, 'trusty')
+
 
 class NetworkConfigFetchingTests(Base):
     """Configuration files can be specified via URL that is then fetched."""
